@@ -19,6 +19,12 @@ except ImportError:
         raise ImportError('PILKit was unable to import the Python Imaging Library. Please confirm it`s installed and available on your current Python path.')
 
 try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
+    from io import StringIO
+except ImportError as exc:
+    try:
+        from cStringIO import StringIO
+    except ImportError:
+        try:
+            from StringIO import StringIO
+        except ImportError:
+            raise exc
